#ifndef	_STDDEF_H
#define	_STDDEF_H
typedef	int	size_t;
#ifndef	NULL
#define	NULL	0
#endif
#endif	/* _STDDEF_H */
